@@ -15,10 +15,10 @@ SQL::Translator::Parser::PostgreSQL - parser for PostgreSQL
 =head1 DESCRIPTION
 
 The grammar was started from the MySQL parsers.  Here is the description
-from PostgreSQL, truncated to what's currently supported (patches welcome, of course) :
+from PostgreSQL:
 
 Table:
-(http://www.postgresql.org/docs/current/sql-createtable.html)
+(http://www.postgresql.org/docs/view.php?version=7.3&idoc=1&file=sql-createtable.html)
 
   CREATE [ [ LOCAL ] { TEMPORARY | TEMP } ] TABLE table_name (
       { column_name data_type [ DEFAULT default_expr ]
@@ -51,12 +51,11 @@ Table:
   [ DEFERRABLE | NOT DEFERRABLE ]
   [ INITIALLY DEFERRED | INITIALLY IMMEDIATE ]
 
-Index :
-(http://www.postgresql.org/docs/current/sql-createindex.html)
+Index:
+(http://www.postgresql.org/docs/view.php?version=7.3&idoc=1&file=sql-createindex.html)
 
   CREATE [ UNIQUE ] INDEX index_name ON table
       [ USING acc_method ] ( column [ ops_name ] [, ...] )
-      [ INCLUDE  ( column [, ...] ) ]
       [ WHERE predicate ]
   CREATE [ UNIQUE ] INDEX index_name ON table
       [ USING acc_method ] ( func_name( column [, ... ]) [ ops_name ] )
@@ -81,7 +80,7 @@ Alter table:
   ALTER TABLE table
           OWNER TO new_owner
 
-View :
+View table:
 
     CREATE [ OR REPLACE ] VIEW view [ ( column name list ) ] AS SELECT query
 
@@ -90,7 +89,7 @@ View :
 use strict;
 use warnings;
 
-our $VERSION = '1.6_3';
+our $VERSION = '1.59_01';
 
 our $DEBUG;
 $DEBUG   = 0 unless defined $DEBUG;
@@ -237,7 +236,7 @@ create : CREATE temporary(?) TABLE table_id '(' create_definition(s? /,/) ')' ta
         1;
     }
 
-create : CREATE unique(?) /(index|key)/i index_name /on/i table_id using_method(?) '(' field_name(s /,/) ')' include_covering(?) where_predicate(?) ';'
+create : CREATE unique(?) /(index|key)/i index_name /on/i table_id using_method(?) '(' field_name(s /,/) ')' where_predicate(?) ';'
     {
         my $table_info  = $item{'table_id'};
         my $schema_name = $table_info->{'schema_name'};
@@ -250,7 +249,6 @@ create : CREATE unique(?) /(index|key)/i index_name /on/i table_id using_method(
                 fields    => $item[9],
                 method    => $item{'using_method(?)'}[0],
                 where     => $item{'where_predicate(?)'}[0],
-                include   => $item{'include_covering(?)'}[0]
             }
         ;
     }
@@ -266,19 +264,6 @@ create : CREATE or_replace(?) temporary(?) VIEW view_id view_fields(?) /AS/i vie
         }
     }
 
-create: CREATE /MATERIALIZED VIEW/i if_not_exists(?) view_id view_fields(?) /AS/i view_target ';'
-    {
-        push @views, {
-            schema_name  => $item{view_id}{schema_name},
-            view_name    => $item{view_id}{view_name},
-            sql          => $item{view_target},
-            fields       => $item[5],
-            extra        => { materialized => 1 }
-        }
-    }
-
-if_not_exists : /IF NOT EXISTS/i
-
 trigger_name : NAME
 
 trigger_scope : /FOR/i /EACH/i /(ROW|STATEMENT)/i { $return = lc $1 }
@@ -317,9 +302,6 @@ using_method : /using/i WORD { $item[2] }
 
 where_predicate : /where/i /[^;]+/
 
-include_covering : /include/i '(' covering_field_name(s /,/) ')'
-  { $item{'covering_field_name(s)'} }
-
 create_definition : field
     | table_constraint
     | <error>
@@ -384,7 +366,6 @@ column_name : NAME '.' NAME
 comment_phrase : /null/i
     { $return = 'NULL' }
     | SQSTRING
-    | DOLLARSTRING
 
 field : field_comment(s?) field_name data_type field_meta(s?) field_comment(s?)
     {
@@ -521,8 +502,6 @@ schema_name : NAME
 
 field_name : NAME
 
-covering_field_name : NAME
-
 double_quote: /"/
 
 index_name : NAME
@@ -1109,7 +1088,6 @@ sub parse {
             my @options = ();
             push @options, { using => $idata->{'method'} } if $idata->{method};
             push @options, { where => $idata->{'where'} }  if $idata->{where};
-            push @options, { include => $idata->{'include'} } if $idata->{include};
             my $index  =  $table->add_index(
                 name    => $idata->{'name'},
                 type    => uc $idata->{'type'},
