@@ -133,7 +133,7 @@ like-op::=
 use strict;
 use warnings;
 
-our $VERSION = '1.6_3';
+our $VERSION = '1.59_01';
 
 our $DEBUG;
 $DEBUG   = 0 unless defined $DEBUG;
@@ -477,8 +477,7 @@ column_list : field_name(s /,/)
 parens_value_list : '(' VALUE(s /,/) ')'
     { $item[2] }
 
-expr : /[^)]* \( [^)]+ \) [^)]*/x # parens, balanced one deep
-    | /[^)]+/
+expr : /[^)]+/
 
 sort_order : /(ASC|DESC)/i
 
