@@ -20,7 +20,7 @@ This module will produce text output of the schema suitable for Sybase.
 use strict;
 use warnings;
 our ( $DEBUG, $WARN );
-our $VERSION = '1.6_3';
+our $VERSION = '1.59_01';
 $DEBUG = 1 unless defined $DEBUG;
 
 use Data::Dumper;
@@ -123,10 +123,8 @@ sub produce {
     my $add_drop_table = $translator->add_drop_table;
     my $schema         = $translator->schema;
 
-    my @output;
-    push @output, header_comment unless ($no_comments);
-
-    my @foreign_keys;
+    my $output;
+    $output .= header_comment unless ($no_comments);
 
     for my $table ( $schema->get_tables ) {
         my $table_name    = $table->name or next;
@@ -165,8 +163,6 @@ sub produce {
             my $commalist      = join( ', ', map { qq['$_'] } @$list );
             my $seq_name;
 
-            my $identity = '';
-
             if ( $data_type eq 'enum' ) {
                 my $check_name = mk_name(
                     $table_name.'_'.$field_name, 'chk' ,undef, 1
@@ -178,10 +174,10 @@ sub produce {
             elsif ( $data_type eq 'set' ) {
                 $data_type .= 'character varying';
             }
+            elsif ( $field->is_auto_increment ) {
+                $field_def .= ' IDENTITY';
+            }
             else {
-                if ( $field->is_auto_increment ) {
-                    $identity = 'IDENTITY';
-                }
                 if ( defined $translate{ $data_type } ) {
                     $data_type = $translate{ $data_type };
                 }
@@ -213,7 +209,6 @@ sub produce {
 
             $field_def .= " $data_type";
             $field_def .= "($size)" if $size;
-            $field_def .= " $identity" if $identity;
 
             #
             # Default value
@@ -262,8 +257,8 @@ sub produce {
             }
             elsif ( $type eq FOREIGN_KEY ) {
                 $name ||= mk_name( $table_name, 'fk', undef,1 );
-                push @foreign_keys,
-                    "ALTER TABLE $table ADD CONSTRAINT $name FOREIGN KEY".
+                push @constraint_defs,
+                    "CONSTRAINT $name FOREIGN KEY".
                     ' (' . join( ', ', @fields ) . ') REFERENCES '.
                     $constraint->reference_table.
                     ' (' . join( ', ', @rfields ) . ')';
@@ -286,23 +281,25 @@ sub produce {
             push @index_defs,
                 'CREATE INDEX ' . $index->name .
                 " ON $table_name (".
-                join( ', ', $index->fields ) . ")";
+                join( ', ', $index->fields ) . ");";
         }
 
-        my $drop_statement = $add_drop_table
-            ? qq[DROP TABLE $table_name_ur] : '';
-        my $create_statement = qq[CREATE TABLE $table_name_ur (\n].
+        my $create_statement;
+        $create_statement  = qq[DROP TABLE $table_name_ur;\n]
+            if $add_drop_table;
+        $create_statement .= qq[CREATE TABLE $table_name_ur (\n].
             join( ",\n",
                 map { "  $_" } @field_defs, @constraint_defs
             ).
-            "\n)"
+            "\n);"
         ;
 
-        $create_statement = join("\n\n", @comments) . "\n\n" . $create_statement;
-        push @output,
+        $output .= join( "\n\n",
+            @comments,
             $create_statement,
             @index_defs,
-        ;
+            ''
+        );
     }
 
     foreach my $view ( $schema->get_views ) {
@@ -314,7 +311,7 @@ sub produce {
         # text of view is already a 'create view' statement so no need
         # to do anything fancy.
 
-        push @output, join("\n\n",
+        $output .= join("\n\n",
                        @comments,
                        $view->sql(),
                        );
@@ -333,12 +330,11 @@ sub produce {
         # think about doing fancy stuff with granting permissions and
         # so on.
 
-        push @output, join("\n\n",
+        $output .= join("\n\n",
                        @comments,
                        $procedure->sql(),
                        );
     }
-    push @output, @foreign_keys;
 
     if ( $WARN ) {
         if ( %truncated ) {
@@ -353,7 +349,7 @@ sub produce {
         }
     }
 
-    return wantarray ? @output : join ";\n\n", @output;
+    return $output;
 }
 
 sub mk_name {
